@@ -2,7 +2,7 @@
 
 use tokio::time::{Duration, sleep};
 
-use syslog_rs::sy_async::{Syslog};
+use syslog_rs::sy_async::{Syslog, SyslogStd, SyslogExt};
 use syslog_rs::{LogStat, LogFacility, Priority, UnsafeReadOnlyCell};
 
 lazy_static! {
@@ -11,7 +11,6 @@ lazy_static! {
 }
 
 
-
 macro_rules! logdebug 
 {
     ($($arg:tt)*) => (
@@ -34,6 +33,13 @@ async fn main()
 
     logdebug!("test message!");
     
+    SYSLOG.vsyslog(Priority::LOG_DEBUG, "test 2").await;
+
+    sleep(Duration::from_micros(10)).await;
+
+    SYSLOG.change_identity("new_identity").await;
+
+    logdebug!("test message new identity!");
 
     sleep(Duration::from_micros(10)).await;
 
