@@ -4,7 +4,7 @@ use std::thread;
 use std::time::{Duration};
 
 #[cfg(feature = "use_sync")]
-use syslog_rs::sy_sync::{Syslog, SyslogCommon};
+use syslog_rs::sy_sync::{Syslog, SyslogStd};
 use syslog_rs::{LogStat, LogFacility, Priority, UnsafeReadOnlyCell};
 
 lazy_static! {
