@@ -1,24 +1,21 @@
 
 #[macro_use] extern crate lazy_static;
 
-use std::sync::Arc;
 use std::thread;
 use std::time::Duration;
 
 #[cfg(feature = "use_sync")]
-use syslog_rs::sy_sync::{Syslog, SyslogCommon};
+use syslog_rs::sy_sync::{Syslog, SyslogStd};
 
 use syslog_rs::{LogStat, LogFacility, Priority};
 
 lazy_static! {
-    static ref SYSLOG: Arc<Syslog> = 
-        Arc::new(
-            Syslog::openlog(
-                Some("example"), 
-                LogStat::LOG_CONS | LogStat::LOG_NDELAY | LogStat::LOG_PID, 
-                LogFacility::LOG_DAEMON
-            ).unwrap()
-        );
+    static ref SYSLOG: Syslog = 
+        Syslog::openlog(
+            Some("example"), 
+            LogStat::LOG_CONS | LogStat::LOG_NDELAY | LogStat::LOG_PID, 
+            LogFacility::LOG_DAEMON
+        ).unwrap();
 }
 
 macro_rules! logdebug 
