@@ -5,9 +5,7 @@ use std::thread;
 use std::time::Duration;
 
 #[cfg(feature = "use_sync")]
-use syslog_rs::sy_sync::{Syslog, SyslogCommon};
-
-use std::fmt::Write;
+use syslog_rs::sy_sync::{Syslog, SyslogStd, SyslogExt};
 
 use syslog_rs::{LogStat, LogFacility, Priority};
 
