@@ -9,10 +9,14 @@
  */
 
 
+use std::path::Path;
+
+use tokio::net::UnixDatagram;
 use tokio::time::{sleep, Duration};
 use tokio::sync::Mutex;
 
 use async_recursion::async_recursion;
+use async_trait::async_trait;
 
 use chrono::offset::Local;
 
@@ -27,13 +31,12 @@ use nix::libc;
 ))]
 use chrono::SecondsFormat;
 
-use super::async_socket::*;
 use crate::portable;
 use crate::common::*;
 use crate::error::{SyRes};
 
-// https://docs.rs/tokio/1.6.1/tokio/net/struct.UnixDatagram.html#method.unbound
-// https://docs.rs/tokio/1.6.1/tokio/sync/struct.Mutex.html
+use super::async_socket::*;
+pub use super::syslog_trait::{SyslogStd, SyslogExt};
 
 /// Internal structure with syslog setup
 struct SyslogInternal
@@ -51,11 +54,11 @@ struct SyslogInternal
     logmask: i32,
 
     /// A stream
-    stream: SyslogSocket,
+    stream: Box<dyn AsyncSyslogTap + Send>,
 }
 
-unsafe impl Sync for SyslogInternal{}
-unsafe impl Send for SyslogInternal{}
+//unsafe impl Sync for SyslogInternal{}
+//unsafe impl Send for SyslogInternal{}
 
 // Drop is called when no more references are left.
 impl Drop for SyslogInternal 
@@ -72,38 +75,40 @@ impl SyslogInternal
         logtag: Option<&str>, 
         logstat: LogStat,
         facility: LogFacility,
-        logmask: i32,
-        stream: SyslogSocket
-    ) -> SyRes<Self>
+        opt_path: Option<&Path>
+    ) -> Self
     {
-        let logtag = 
+        // check if log_facility is invalid
+        let log_facility =
+            if facility.is_empty() == false && 
+                (facility & !LogMask::LOG_FACMASK).is_empty() == true
+            {
+                facility
+            }
+            else
+            {
+                // default facility code
+                LogFacility::LOG_USER
+            };
+
+        let ident = 
             match logtag
             {
-                Some(r) => Some(r.to_string()),
+                Some(r) => Some(truncate_n(r, RFC_MAX_APP_NAME)),
                 None => None,
             };
-
-        let mut inst = 
+                
+        return 
             Self
             {
-                logtag,
-                logstat,
-                facility,
-                logmask,
-                stream
+                logtag: ident,
+                logstat: logstat, 
+                facility: log_facility,
+                logmask: 0xff,
+                stream: AsyncTap::<UnixDatagram>::new(opt_path),
             };
-
-        if inst.logstat.intersects(LogStat::LOG_NDELAY) == true
-        {
-            inst.connectlog()?;
-        }
-
-        return Ok(inst);
     }
-}
 
-impl SyslogInternal
-{
     pub(crate) 
     fn set_logmask(&mut self, logmask: i32) -> i32
     {
@@ -149,12 +154,7 @@ impl SyslogInternal
     /// Should be called only when lock is acuired
     fn disconnectlog(&mut self)
     {
-        if self.stream.is_none() == false
-        {
-            self.stream.shutdown();
-
-            self.stream = SyslogSocket::none();
-        }
+        let _ = self.stream.disconnectlog();
     }
 
     /// Connects unix stream to the syslog and sets up the properties of
@@ -162,11 +162,7 @@ impl SyslogInternal
     /// Should be called only when lock is acuired
     fn connectlog(&mut self) -> SyRes<()>
     {
-        let stream = SyslogSocket::connect()?;
-
-        self.stream = stream;
-
-        return Ok(());
+        return self.stream.connectlog();
     }
     
     /// An internal function which is called by the syslog or vsyslog.
@@ -273,7 +269,7 @@ impl SyslogInternal
                 msg.as_slice()
             ].concat();
 
-        if self.stream.is_none() == true
+        if self.stream.is_connected() == false
         {
             // open connection
             match self.connectlog()
@@ -467,7 +463,7 @@ impl SyslogInternal
                 msg.as_slice()
             ].concat();
 
-        if self.stream.is_none() == true
+        if self.stream.is_connected() == true
         {
             // open connection
             match self.connectlog()
@@ -562,11 +558,9 @@ pub struct Syslog
 unsafe impl Send for Syslog {}
 unsafe impl Sync for Syslog {}
 
-/// Private realization. It is assumed that functions which are called,
-/// are called after 'lock' is locked.
 
-/// A public implementations
-impl Syslog
+#[async_trait]
+impl SyslogStd for Syslog
 {
     /// As in a libc, this function initializes the syslog instance. The 
     /// main difference with realization in C is it returns the instance
@@ -593,7 +587,7 @@ impl Syslog
     ///         LogStat::LOG_NDELAY | LogStat::LOG_PID, 
     ///         LogFacility::LOG_DAEMON);
     /// ```
-    pub async 
+    async 
     fn openlog(
         ident: Option<&str>, 
         logstat: LogStat, 
@@ -601,14 +595,18 @@ impl Syslog
     ) -> SyRes<Self>
     {
 
-        let inner = 
+        let mut inner = 
             SyslogInternal::new(
                 ident,
                 logstat,
                 facility,
-                0xff,
-                SyslogSocket::none()
-            )?;
+                None
+            );
+
+        if logstat.contains(LogStat::LOG_NDELAY) == true
+        {
+            inner.connectlog()?;
+        }
 
         let ret = 
             Self
@@ -631,7 +629,7 @@ impl Syslog
     ///
     /// ~(LOG_MASK!(Priority::LOG_INFO))
     /// LOG_UPTO!(Priority::LOG_ERROR)
-    pub async 
+    async 
     fn setlogmask(&self, logmask: i32) -> i32
     {
         return 
@@ -642,7 +640,7 @@ impl Syslog
     }
 
     /// Similar to libc, closelog() will close the log
-    pub async 
+    async 
     fn closelog(&self)
     {
         self.lock.lock().await.disconnectlog();
@@ -657,7 +655,7 @@ impl Syslog
     /// * `fmt` - a string message. In C exists a functions with
     ///     variable argumets amount. In Rust you should create your
     ///     own macros like format!() or use format!()]
-    pub async 
+    async 
     fn syslog(&self, pri: Priority, fmt: String)
     {
         self.lock
@@ -668,17 +666,51 @@ impl Syslog
     }
 
     /// Similar to syslog() and created for the compatability.
-    pub async 
-    fn vsyslog<S: AsRef<str>>(&self, pri: Priority, fmt: S)
+    async 
+    fn vsyslog<S: AsRef<str> + Send>(&self, pri: Priority, fmt: S)
     {
+        let f = fmt.as_ref();
         self.lock
             .lock()
             .await
-            .vsyslog1(pri.bits(), fmt.as_ref())
+            .vsyslog1(pri.bits(), f)
             .await;
     }
+}
 
-    // --- NON STANDART API
+// --- NON STANDART API
+#[async_trait]
+impl SyslogExt for Syslog
+{
+    /// NON STANDARD FUNCTION
+    /// 
+    /// This function acting like `openlog()` but allows to open connection to 
+    /// the arbitrary object.
+    /// 
+    /// # Arguments
+    /// 
+    /// * @see `openlog()`
+    /// 
+    /// * `sock_path` - [AsRef] [Path] a path to the unix datagram socket
+    async
+    fn openlog_custom<P>(ident: Option<&str>, logstat: LogStat, facility: LogFacility, sock_path: P) -> SyRes<Self>
+    where P: AsRef<Path> + Send
+    {
+        let mut syslog = 
+            SyslogInternal::new(ident, logstat, facility, Some(sock_path.as_ref()));
+       
+        if logstat.contains(LogStat::LOG_NDELAY) == true
+        {
+            syslog.connectlog()?;
+        }
+
+        return Ok( 
+            Self
+            {
+                lock: Mutex::new(syslog),
+            }
+        );
+    }
 
     /// This function can be used to update the facility name, for example
     /// after fork().
@@ -686,8 +718,8 @@ impl Syslog
     /// # Arguments
     /// 
     /// * `ident` - a new identity (up to 48 UTF8 chars)
-    pub async 
-    fn change_identity<I: AsRef<str>>(&self, ident: I)
+    async 
+    fn change_identity<I: AsRef<str> + Send>(&self, ident: I)
     {
         self.lock.lock().await.set_logtag(ident);
     }
@@ -720,8 +752,9 @@ async fn test_multithreading()
                 sleep(Duration::from_nanos(200)).await;
                 tokio::spawn( async move 
                 {
+                    let m = format!("a message from thread 1 #{}[]", i);
                     let now = Instant::now();
-                    cc_c1_log.syslog(Priority::LOG_DEBUG, format!("a message from thread 1 #{}[]", i)).await;
+                    cc_c1_log.syslog(Priority::LOG_DEBUG, m).await;
                     let elapsed = now.elapsed();
                     println!("t1: {:?}", elapsed);
                 });
@@ -737,16 +770,18 @@ async fn test_multithreading()
                 sleep(Duration::from_nanos(201)).await;
                 tokio::spawn( async move 
                 {
+                    let m = format!("сообщение от треда 2 №{}ХЪ", i);
                     let now = Instant::now();
-                    cc_c2_log.syslog(Priority::LOG_DEBUG, format!("сообщение от треда 2 №{}ХЪ", i)).await;
+                    cc_c2_log.vsyslog(Priority::LOG_DEBUG, m).await;
                     let elapsed = now.elapsed();
                     println!("t2: {:?}", elapsed);
                 });
             }
         });
 
+    let m = format!("A message from main, сообщение от главнюка");
     let now = Instant::now();
-    log.syslog(Priority::LOG_DEBUG, format!("A message from main, сообщение от главнюка")).await;
+    log.syslog(Priority::LOG_DEBUG, m).await;
     let elapsed = now.elapsed();
     println!("main: {:?}", elapsed);
 
