@@ -1,8 +1,5 @@
 pub mod syslog_trait;
 
-#[cfg(feature = "use_sync")]
-pub mod syslog_sync;
-
 //-- SYNC MUTEX
 #[cfg(feature = "use_atomic_block")]
 mod mutex;
@@ -10,11 +7,16 @@ mod mutex;
 mod poison;
 
 
+//-- SYNC --
+#[cfg(feature = "use_sync")]
+pub mod syslog_sync;
+
 //-- SYNC QUEUE --
 #[cfg(feature = "use_sync_queue")]
 pub mod syslog_sync_queue;
 
-#[cfg(any(feature = "use_sync_queue", feature = "use_sync"))]
+pub mod syslog_stream;
+
 pub mod syslog_sync_internal;
 
 //-- SYNC SOCKET --
