@@ -113,13 +113,6 @@ impl SyncSyslogInternal
             };
     }
 
-    pub(crate) 
-    fn new_path<P>(ident: Option<&str>, logstat: LogStat, facility: LogFacility, sock_path: P) -> Self
-    where P: AsRef<Path>
-    {
-        return Self::new(ident, logstat, facility, Some(sock_path.as_ref()));
-    }
-
     fn send_to_stderr(&self, msg: &mut [u8])
     {
         if self.logstat.intersects(LogStat::LOG_PERROR) == true
@@ -150,7 +143,8 @@ impl SyncSyslogInternal
     pub(crate) 
     fn set_logtag<L: AsRef<str>>(&mut self, logtag: L)
     {
-        self.logtag = Some(truncate_n(logtag.as_ref(), RFC_MAX_APP_NAME));
+        self.logtag = 
+            Some(truncate_n(logtag.as_ref(), RFC_MAX_APP_NAME));
     }
 
     /// Disconnects the unix stream from syslog.
@@ -355,7 +349,8 @@ impl SyncSyslogInternal
         target_os = "netbsd",
         target_os = "macos"
     ))]
-    pub(crate) fn vsyslog1<S: AsRef<str>>(&mut self, mut pri: i32, fmt: S)
+    pub(crate) 
+    fn vsyslog1<S: AsRef<str>>(&mut self, mut pri: i32, fmt: S)
     {
         // check for invalid bits
         match check_invalid_bits(&mut pri)
