@@ -1,3 +1,5 @@
+use syslog_rs::sync::syslog_trait::SyslogExt;
+
 #[macro_use] extern crate lazy_static;
 #[test]
 fn test_cell()
@@ -6,7 +8,7 @@ fn test_cell()
     use std::time::{Instant, Duration};
 
     #[cfg(feature = "use_sync")]
-    use syslog_rs::sy_sync::{Syslog, SyslogCommon};
+    use syslog_rs::sy_sync::{Syslog, SyslogStd};
     use syslog_rs::{LogStat, LogFacility, Priority, UnsafeReadOnlyCell};
 
     lazy_static! {
